==> fr.ac6.library.st_3.1.0.202303061651.jar: contents/library-soc-stm32mp157/kernels/linux-stm32mp_5.15.67-stm32mp-r2/buildsteps/scripts/install-image-append.sh <==
# Append script for task Install: task.install.linux-stm32mp_5.15.67-stm32mp-r2-r0 (install-append.sh)
# This script was imported from Yocto but may have been modified locally

bbwarn() {
	if [ -p ${workDir}/temp/fifo.29532 ] ; then
		printf "%b\0" "bbwarn $*" > ${workDir}/temp/fifo.29532
	else
		echo "WARNING: $*"
	fi
}

install_helper() {
	if [ -f "u-boot.dtb" ]; then
		# UBOOT_DTB_BINARY is a symlink to UBOOT_DTB_IMAGE, so we
		# need both of them.
		log_run install -Dm 0644 u-boot.dtb ${installDir}${datadir}/u-boot-stm32mp15-eval-5.15.67-stm32mp-r2-r0.dtb
		log_run ln -sf u-boot-stm32mp15-eval-5.15.67-stm32mp-r2-r0.dtb ${installDir}${datadir}/u-boot.dtb
	else
		bbwarn "u-boot.dtb not found"
	fi
}

install_spl_helper() {
	if [ -f "spl/u-boot-spl.dtb" ]; then
		log_run install -Dm 0644 spl/u-boot-spl.dtb ${installDir}${datadir}/u-boot-spl-stm32mp15-eval-5.15.67-stm32mp-r2-r0.dtb
		log_run ln -sf u-boot-spl-stm32mp15-eval-5.15.67-stm32mp-r2-r0.dtb ${installDir}${datadir}/u-boot-spl.dtb
	else
		bbwarn "u-boot-spl.dtb not found"
	fi
	if [ -f "u-boot-nodtb.bin" ] ; then
		log_run install -Dm 0644 u-boot-nodtb.bin ${installDir}${datadir}/u-boot-nodtb-stm32mp15-eval-5.15.67-stm32mp-r2-r0.bin
		log_run ln -sf u-boot-nodtb-stm32mp15-eval-5.15.67-stm32mp-r2-r0.bin ${installDir}${datadir}/u-boot-nodtb.bin
	else
		bbwarn "u-boot-nodtb.bin not found"
	fi

	# We need to install a 'stub' u-boot-fitimage + its to datadir,
	# so that the KERNEL_PN can use the correct filename when
	# assembling and deploying them
	touch ${installDir}/${datadir}/u-boot-fitImage-stm32mp15-eval-5.15.67-stm32mp-r2-r0
	touch ${installDir}/${datadir}/u-boot-its-stm32mp15-eval-5.15.67-stm32mp-r2-r0
}

	log_run install -d ${installDir}${sysconfdir}/modules-load.d ${installDir}${sysconfdir}/modprobe.d
	if [ "${recipe_name}" = "u-boot-stm32mp" ]; then
		if [ -n " trusted_stm32mp15 " ]; then
			for config in  stm32mp15_defconfig; do
				cd ${buildDir}/$config
				if [ "0" = "1" -o "0" = "1" ] && \
					[ -n "u-boot.dtb" ]; then
					install_helper
				fi
				if [ "0" = "1" -a -n "u-boot-spl.dtb" ]; then
					install_spl_helper
				fi
			done
		else
			cd ${buildDir}
			if [ "0" = "1" -o "0" = "1" ] && \
				[ -n "u-boot.dtb" ]; then
				install_helper
			fi
			if [ "0" = "1" -a -n "u-boot-spl.dtb" ]; then
				install_spl_helper
			fi
		fi
	fi
	
	log_run install -d ${installDir}/boot
	for dtbf in  ${devicetree}.dtb ; do
		log_run install -m 0644 ${buildDir}/arch/arm/boot/dts/$dtbf ${installDir}/boot/$dtbf
	done
    # Install KERNEL_IMAGETYPE for kernel-imagebootfs package
    log_run install -m 0644 ${buildDir}/arch/arm/boot/${image_format} ${installDir}/boot

    if true; then
	# when ACCEPT_EULA are filled
	echo "blacklist etnaviv" > ${installDir}/${sysconfdir}/modprobe.d/blacklist.conf
    fi
    #snd dependencies
    log_run install -d ${installDir}/${sysconfdir}/modprobe.d
    echo "softdep snd-soc-cs42l51 pre: snd-soc-cs42l51-i2c" > ${installDir}/${sysconfdir}/modprobe.d/stm32mp1-snd.conf

==> fr.ac6.library.st_3.1.0.202305241525.jar: contents/library-soc-stm32mp157/kernels/linux-stm32mp_5.15.67-stm32mp-r2/buildsteps/scripts/install-image-append.sh <==
# Append script for task Install: task.install.linux-stm32mp_5.15.67-stm32mp-r2-r0 (install-append.sh)
# This script was imported from Yocto but may have been modified locally

install_helper() {
	if [ -f "u-boot.dtb" ]; then
		# UBOOT_DTB_BINARY is a symlink to UBOOT_DTB_IMAGE, so we
		# need both of them.
		log_run install -Dm 0644 u-boot.dtb ${installDir}${datadir}/u-boot-stm32mp15-eval-5.15.67-stm32mp-r2-r0.dtb
		log_run ln -sf u-boot-stm32mp15-eval-5.15.67-stm32mp-r2-r0.dtb ${installDir}${datadir}/u-boot.dtb
	else
		warning "u-boot.dtb not found"
	fi
}

install_spl_helper() {
	if [ -f "spl/u-boot-spl.dtb" ]; then
		log_run install -Dm 0644 spl/u-boot-spl.dtb ${installDir}${datadir}/u-boot-spl-stm32mp15-eval-5.15.67-stm32mp-r2-r0.dtb
		log_run ln -sf u-boot-spl-stm32mp15-eval-5.15.67-stm32mp-r2-r0.dtb ${installDir}${datadir}/u-boot-spl.dtb
	else
		warning "u-boot-spl.dtb not found"
	fi
	if [ -f "u-boot-nodtb.bin" ] ; then
		log_run install -Dm 0644 u-boot-nodtb.bin ${installDir}${datadir}/u-boot-nodtb-stm32mp15-eval-5.15.67-stm32mp-r2-r0.bin
		log_run ln -sf u-boot-nodtb-stm32mp15-eval-5.15.67-stm32mp-r2-r0.bin ${installDir}${datadir}/u-boot-nodtb.bin
	else
		warning "u-boot-nodtb.bin not found"
	fi

	# We need to install a 'stub' u-boot-fitimage + its to datadir,
	# so that the KERNEL_PN can use the correct filename when
	# assembling and deploying them
	touch ${installDir}/${datadir}/u-boot-fitImage-stm32mp15-eval-5.15.67-stm32mp-r2-r0
	touch ${installDir}/${datadir}/u-boot-its-stm32mp15-eval-5.15.67-stm32mp-r2-r0
}

	log_run install -d ${installDir}${sysconfdir}/modules-load.d ${installDir}${sysconfdir}/modprobe.d
	if [ "${recipe_name}" = "u-boot-stm32mp" ]; then
		if [ -n " trusted_stm32mp15 " ]; then
			for config in  stm32mp15_defconfig; do
				cd ${buildDir}/$config
				if [ "0" = "1" -o "0" = "1" ] && \
					[ -n "u-boot.dtb" ]; then
					install_helper
				fi
				if [ "0" = "1" -a -n "u-boot-spl.dtb" ]; then
					install_spl_helper
				fi
			done
		else
			cd ${buildDir}
			if [ "0" = "1" -o "0" = "1" ] && \
				[ -n "u-boot.dtb" ]; then
				install_helper
			fi
			if [ "0" = "1" -a -n "u-boot-spl.dtb" ]; then
				install_spl_helper
			fi
		fi
	fi
	
	log_run install -d ${installDir}/boot
	for dtbf in  ${devicetree}.dtb ; do
		log_run install -m 0644 ${buildDir}/arch/arm/boot/dts/$dtbf ${installDir}/boot/$dtbf
	done
    # Install KERNEL_IMAGETYPE for kernel-imagebootfs package
    log_run install -m 0644 ${buildDir}/arch/arm/boot/${image_format} ${installDir}/boot

    if true; then
		# when ACCEPT_EULA are filled
		echo "blacklist etnaviv" > ${installDir}/${sysconfdir}/modprobe.d/blacklist.conf
    fi
    #snd dependencies
    log_run install -d ${installDir}/${sysconfdir}/modprobe.d
    echo "softdep snd-soc-cs42l51 pre: snd-soc-cs42l51-i2c" > ${installDir}/${sysconfdir}/modprobe.d/stm32mp1-snd.conf
